package cn.cecep.talroad.mapper;


import cn.cecep.talroad.domain.leader.vo.*;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 领导驾驶舱持久层
 */
public interface LeaderCockpitMapper {

    List<StationTypeDictVO> selectStationTypeList();

    /**
     * 地图上层的三个数量
     * @return
     */
    MapUpVo selectMapUpCount();

    /**
     * 获取数据库总条数
     * @return
     */
    Long getDatabaseDataCount();


    /**
     * 企业管理类型统计数量
     * @return
     */
    ManTypeVO getFactoryManTypeCount();

    /**
     * 企业接入数据类型数量
     * @return
     */
    List<DataTypeVO>getFactoryDataTypeCount();

    /**
     * 设备数量查询
     * @return
     */
    DeviceCountVO selectDeviceCount();

    /**
     * 查询排口总数量
     * @return
     */
    OutletCountVO selectOutletCount();


    /**
     * 获取问题类型大小类数量
     * @return
     */
    ProblemTypeCountVO selectProblemTypeCount();

    /**
     * 获取问题处置情况数量
     * @return
     */
    ProblemDoingCountVO selectProblemDoingCount();

    /**
     * 大类分组查询问题数量
     * @return
     */
    List<ProblemGroupCountVO> selectProblemOneLevelGroupCount();

    /**
     * 小类分组查询问题数量
     * @return
     */
    List<ProblemGroupCountVO>  selectProblemTwoLevelGroupCount(@Param("problemId") String problemId);

    /**
     * 获取唐山最新空气质量排名
     */
    AirQualityDataVO getCityAirQualityData();
}
